formattools.get_markup_format_contributions
===========================================

.. autofunction:: abjad.tools.formattools.get_markup_format_contributions.get_markup_format_contributions
   :noindex:
